<!--群组管理-->
<template>
  <div class="mobile-device">
    <!--  头部  -->
    <van-sticky>
      <van-nav-bar
        title="群组管理"
        left-arrow
        @click-left="
                    (_) => $router.go(-1)
                "

      >
        <template #right>
          <van-icon name="search" size="18" @click="showPopup('querySearchPopup')" />
          <van-icon name="add-o" @click="goSecurityInvestigationPlan({},'新增')" style="margin:0 0 0 10px" size="18" />
        </template>
      </van-nav-bar>
    </van-sticky>

    <div>
      <van-pull-refresh
        v-model="refreshing"
        @refresh="onRefresh"
        class="van-hairline--top"
      >
        <van-list
          v-model="loading"
          :finished="finished"
          finished-text="没有更多了"
          @load="onLoad"
          :immediate-check="false"
        >
          <div
            v-for="(item, index) in listData"
            :key="index"
            class="device van-hairline--bottom"
            :class="{myStyle: index === listData.length - 1}"
            @click="goSecurityInvestigationPlan(item,'编辑')"
          >
            <div class="device-item">
              <div class="left-cont">
                <img src="@/assets/img/qunzu.png" alt="" />
              </div>
              <div class="right-cont">
                <div class="device-item-text">
                  <div
                    class="device-item-content"
                    style="margin-bottom: 6px"
                  >
                    <div>
                      <div class="device-name">
                        {{ item.name }}
                      </div>
                    </div>
                  </div>
                </div>
                <div class="device-content">
                  <p>
                                        <span style="color: #333">编码：</span
                                        >{{ item.code }}
                  </p>
                  <p>
                    <span style="color: #333">描述：</span>
                    {{ item.description }}
                    <!-- {{
                    dictionaryEscape(
                        unitsTypeOpt,
                        item.type
                    )
                }} -->
                  </p>
                </div>
              </div>
            </div>
          </div>
        </van-list>
      </van-pull-refresh>
    </div>
    <!-- 列表筛选弹层 -->
    <QuerySearchPopup
      :querySearchPopup.sync="querySearchPopup"
      :customQueryPrams="customQueryPrams"
      @searchData="searchData"
    />
  </div>
</template>

<script>
import GroupManagement from '@/api/device/GroupManagement.js'
import dictUtils from '@/components/dict/DictSelectUtils'
import QuerySearchPopup from './components/QuerySearchPopup/index.vue'

const {infoQuery} = GroupManagement

export default {
  name: 'GroupManagement',
  components: {QuerySearchPopup},
  // 群组管理
  data() {
    return {
      // 自定义请求参数配置对象
      customQueryPrams: {
        pageSize: 10,
        page: 1,
        name: '', // 名称
        code: '' // 编码
      },
      listData: [], // 列表数据
      loading: false, // 列表是否触发loading
      finished: false, // 列表是否加载完成
      refreshing: false, // 列表是否开始下拉刷新
      querySearchPopup: false // 搜索弹层
    }
  },
  computed: {
    // 加工为后端需要的请求格式
    queryParams() {
      const {pageSize, page, ...item} = this.customQueryPrams
      /*
       * 定义 escapeOpt 字段对应字典名 对象，后续进行字段的翻译逻辑
       *  为重新加工结构赋值的新请求配置参数
       * */
      const querys = [
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'name',
          relation: 'AND'
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'code',
          relation: 'AND'
        }
      ]
      const escapeOpt = {}
      return {
        pageBean: {pageSize, page},
        querys: querys.map((i) => {
          let value = item[i.property]
          let escape = this[escapeOpt[i.property]]
          if (!escape) return {...i, value}
          value = this.dictionaryEscape(escape, value, {
            dictionaryType: false
          })
          return {...i, value}
        })
      }
    }
  },
  created() {
    this.getListData()
  },
  methods: {
    // 字典转义(转义、翻译)
    dictionaryEscape(dictionary, val, option = {}) {
      if (!(Array.isArray(dictionary) && dictionary.length)) return ''
      option = {
        valueKey: 'value',
        labelKey: 'text',
        dictionaryType: true, // true 为转义 false 为翻译
        ...option
      }
      const {valueKey, labelKey, dictionaryType} = option
      let item =
        dictionary.find(
          (i) => i[dictionaryType ? valueKey : labelKey] === val
        ) || {}
      return item[dictionaryType ? labelKey : valueKey] || ''
    },

    // 跳转编辑修改
    goSecurityInvestigationPlan({id}, type) {
      this.$router.push({
        name: 'GroupManagementForm',
        query: {id, type}
      })
    },
    // 触底时触发
    onLoad() {
      this.customQueryPrams.page++
      this.getListData((_) => (this.loading = false))
    },

    // 下拉时触发
    onRefresh() {
      this.customQueryPrams.page = 1
      this.listData = []
      this.getListData((_) => (this.refreshing = false))
    },

    // 打开弹层
    showPopup(popupName) {
      this[popupName] = true
    },

    // 获取列表数据
    getListData(callback) {
      infoQuery(this.queryParams, (res) => {
        const {pageSize, page} = this.customQueryPrams
        this.listData = this.listData.concat(res.rows)
        this.$nextTick((_) => callback && callback())
        if (pageSize * page >= res.total) this.finished = true
      })
    },

    // 查询/重置按钮点击
    searchData() {
      this.finished = false
      this.customQueryPrams.page = 1
      this.listData = []
      this.getListData()
    }
  }
}
</script>

<style lang="scss" scoped>
@import '@/assets/css/element-variables';

.van-cell__title span,
.van-cell__value span {
  font-size: 82px;
}

.van-cell__value span {
  color: $--mobile-text-active;
}

::v-deep .device .device-item-text {
  border-bottom: 0;
}

.popup-content {
  height: 86%;
  overflow-y: scroll;
}

.confirm-button {
  width: 90%;
  position: fixed;
  bottom: 20px;
  display: flex;
  justify-content: space-evenly;
}

::v-deep .search-box {
  display: flex;
  justify-content: space-between;
  align-items: center;
  width: 100%;
  z-index: 10;

  .van-search {
    width: 100%;
  }

  // .van-dropdown-menu {
  //   width: 100%;
  //   .van-dropdown-menu__bar {
  //     box-shadow: 0 2px 12px rgba(255, 255, 255, 0.12);
  //   }
  // }
  // .van-search {
  //   flex: 1;
  // }
}

//  ::v-deep .van-dropdown-item {
//   top: 228px !important;
// }

.device {
  background-color: #f9f9f9;
  padding: 40px 40px 20px 40px;
  box-sizing: border-box;
  color: $--mobile-text-sub;
  width: 100%;

  .device-item {
    background-color: #fff;
    border-radius: 60px;
    padding: 20px 100px 20px 100px;
    box-shadow: 0 4px 8px 0 rgba(0, 0, 0, 0.1),
    0 6px 20px 0 rgba(0, 0, 0, 0.1);
    display: flex;
    align-items: center;

    .left-cont {
      img {
        width: 270px;
        // height: 256px;
      }
    }

    .right-cont {
      flex: 1;
      padding-left: 8px;
    }
  }

  .device-content {
    // padding: 50px 0px 50px 0px;
    // height: 400px;
    font-size: 50px;

    p {
      margin: 10px 0 10px 0;
    }
  }

  .device-item-text {
    padding: 20px 0px 10px 0px;
    // margin-left: 10px;
    // width: calc(100% - 256px - 10px);
    border-bottom: 1px solid #dedddd;
  }

  .device-item-content {
    display: flex;
    justify-content: space-between;
    align-items: center;

    span {
      font-size: 72px;
    }
  }

  .device-name {
    font-size: 88px;
    color: $--mobile-text-main;
  }

  .device-name-icon {
    color: $-mobile-primary;
    margin-right: 2px;
  }

  .device-code {
    color: $--mobile-text-sub;
    font-size: 82px;
  }

  .device-item-title {
    color: #49a1f9;
    margin-right: 2px;
  }

  .device-status .van-tag {
    padding: 4px 6px;
  }

  .van-tag {
    width: 200px;
    display: flex;
    justify-content: center;
  }
}

.myStyle {
  padding: 40px 40px 40px 40px;
}
</style>
<style lang="scss">
@import '@/assets/css/vant-custom';
</style>
